==> haskell-mustache-2.4.3.1-31-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.3.1
visibility:           public
id:                   mustache-2.4.3.1-4XzET6erASsEuDK2f9EVGi
key:                  mustache-2.4.3.1-4XzET6erASsEuDK2f9EVGi
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache#readme
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  9de4a26c6c494717e09878912cc63488
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:       Text.Mustache.Internal Text.Mustache.Internal.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.3.1-4XzET6erASsEuDK2f9EVGi
depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.8.0-L88GQ4rEhQfGc3NVSCAVTu template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk
    vector-0.13.2.0-AtXaKVcIvtCInBZOrzSe57

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.4.3.1-56-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mustache
version:              2.4.3.1
visibility:           public
id:                   mustache-2.4.3.1-4RO5pPRLVsu9F6e3tYJNl3
key:                  mustache-2.4.3.1-4RO5pPRLVsu9F6e3tYJNl3
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache#readme
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  1aa5afb07e3a9596bf0c6f645b0bc379
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:       Text.Mustache.Internal Text.Mustache.Internal.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mustache-2.4.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.3.1-4RO5pPRLVsu9F6e3tYJNl3
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 mtl-2.2.2 parsec-3.1.16.1
    scientific-0.3.8.0-6QoqQGQc0yZ1FsULZsdy9C template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.6-HRVeiGNnDxNElRy2LmdExl
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
